pub enum CassandraStatement {
Show 38 variants
AlterKeyspace(CreateKeyspace),
AlterMaterializedView(AlterMaterializedView),
AlterRole(RoleCommon),
AlterTable(AlterTable),
AlterType(AlterType),
AlterUser(CreateUser),
ApplyBatch,
CreateAggregate(Aggregate),
CreateFunction(CreateFunction),
CreateIndex(CreateIndex),
CreateKeyspace(CreateKeyspace),
CreateMaterializedView(CreateMaterializedView),
CreateRole(RoleCommon),
CreateTable(CreateTable),
CreateTrigger(CreateTrigger),
CreateType(CreateType),
CreateUser(CreateUser),
Delete(Delete),
DropAggregate(CommonDrop),
DropFunction(CommonDrop),
DropIndex(CommonDrop),
DropKeyspace(CommonDrop),
DropMaterializedView(CommonDrop),
DropRole(CommonDrop),
DropTable(CommonDrop),
DropTrigger(DropTrigger),
DropType(CommonDrop),
DropUser(CommonDrop),
Grant(Privilege),
Insert(Insert),
ListPermissions(Privilege),
ListRoles(ListRole),
Revoke(Privilege),
Select(Select),
Truncate(FQName),
Update(Update),
Use(Identifier),
Unknown(String),
}Expand description
The Supported Cassandra CQL3 statements Documentation for statements can be found at https://docs.datastax.com/en/cql-oss/3.3/cql/cql_reference/cqlCommandsTOC.html
Variants
AlterKeyspace(CreateKeyspace)
AlterMaterializedView(AlterMaterializedView)
AlterRole(RoleCommon)
AlterTable(AlterTable)
AlterType(AlterType)
AlterUser(CreateUser)
ApplyBatch
CreateAggregate(Aggregate)
CreateFunction(CreateFunction)
CreateIndex(CreateIndex)
CreateKeyspace(CreateKeyspace)
CreateMaterializedView(CreateMaterializedView)
CreateRole(RoleCommon)
CreateTable(CreateTable)
CreateTrigger(CreateTrigger)
CreateType(CreateType)
CreateUser(CreateUser)
Delete(Delete)
DropAggregate(CommonDrop)
DropFunction(CommonDrop)
DropIndex(CommonDrop)
DropKeyspace(CommonDrop)
DropMaterializedView(CommonDrop)
DropRole(CommonDrop)
DropTable(CommonDrop)
DropTrigger(DropTrigger)
DropType(CommonDrop)
DropUser(CommonDrop)
Grant(Privilege)
Insert(Insert)
ListPermissions(Privilege)
ListRoles(ListRole)
Revoke(Privilege)
Select(Select)
Truncate(FQName)
Update(Update)
Use(Identifier)
Unknown(String)
Implementations
sourceimpl CassandraStatement
impl CassandraStatement
sourcepub fn from_tree(tree: &Tree, source: &str) -> Vec<ParsedStatement>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn from_tree(tree: &Tree, source: &str) -> Vec<ParsedStatement>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
extract the cassandra statement from an AST tree.
the boolean return value is true if there is a parsing error in the statement tree.
sourcepub fn from_node(node: &Node<'_>, source: &str) -> CassandraStatement
pub fn from_node(node: &Node<'_>, source: &str) -> CassandraStatement
extract the cassandra statement from an AST node.
pub fn get_keyspace<'a>(&'a self, default: &'a Identifier) -> &'a Identifier
pub fn short_name(&self) -> &'static str
sourcepub fn get_table_name(&self) -> Option<&FQName>
pub fn get_table_name(&self) -> Option<&FQName>
returns the table name from the statement if there is one.