Structs

A column definition. This is used in many places, however the primary_key value should only be used in the create table calls. In all other cases it will yield an invalid statement.
the definition of a data type
a fully qualified name.
the order clause
The definition of a primary key. There must be at least one column specified in the partition.
data item used in Grant, ListPermissions and Revoke statements.
the structure of the TTL / Timestamp option.

Enums

An enumeration of data types.
Identifers are either Quoted or Unquoted.
An object that can be on either side of an Operator
the definition of an option value, is either literal string or a map of Key,value pairs.
the list of privileges recognized by the system.
A relation operator used in WHERE and IF clauses.
A list of resource types recognized by the system
The definition of the items in a WithElement