pub enum Identifier {
    Quoted(String),
    Unquoted(String),
}
Identifers are either Quoted or Unquoted.

  • Unquoted Identifiers: are case insensitive
  • Quoted Identifiers: are case sensitive. double quotes appearing within the quoted string are escaped by doubling (i.e. "foo""bar" is interpreted as foo“bar`)

Quoted lower lower case is equivalent to unquoted mixed case. Quoted( myid ) == Unquoted( myid ) Quoted( myid ) == Unquoted( “myId” ) Quoted( myid ) != Quoted( “myId” )

It is possible to create an Unquoted identifier with an embedded quote (e.g. Identifier::Unquoted( "foo\"bar" )). Note that a quote as the first character in an Unquoted Identifier can cause problems if the Identifier is converted to a string and then parsed again as the second parse will create a Quoted identifier.

Variants

Quoted(String)

This variant is case sensitive “fOo”“bAr”“” is stored as fOo“bAr“

Unquoted(String)

This variant is case insensitive Only ascii alphanumeric and _ characters are allowed in this variant fOo_bAr is stored as fOo_bAr

Implementations

parses strings as returned by the parser into Quoted or Unquoted Identifiers.

  • Unquoted Identifiers: are case insensitive
  • Quoted Identifiers: are case sensitive. double quotes appearing within the quoted string are escaped by doubling (i.e. "foo""bar" is interpreted as foo“bar`)

If the string starts with " it is assumed to be a quoted identifier, the leading and trailing quotes are removed and the internal doubled quotes ("") are converted to simple quotes (").