pub enum Operand {
    Const(String),
    Map(Vec<(String, String)>),
    Set(Vec<String>),
    List(Vec<String>),
    Tuple(Vec<Operand>),
    Column(Identifier),
    Func(String),
    Param(String),
    Null,
}
An object that can be on either side of an Operator

Variants

Const(String)

A constant

Map(Vec<(String, String)>)

a map displays as { String:String, String:String, ... }

Set(Vec<String>)

a set of values. Displays as ( String, String, ...)

List(Vec<String>)

a list of values. Displays as [String, String, ...]

Tuple(Vec<Operand>)

a tuple of values. Displays as { Operand, Operand, ... }

Column(Identifier)

A column name

Func(String)

A function call e.g. foo(bar)

Param(String)

A parameter. The string will either be ‘?’ or ‘:name’

Null

the NULL value.

Implementations

unescapes a CQL string Specifically converts '' to ' and removes the leading and trailing delimiters. For all other strings this is method returns the argument. Valid delimiters are ' and $$

creates an Operand::Const from an unquoted string. if the string contains a ' it will be quoted by the $$ pattern. if it contains $$ and ' it will be quoted by the ' pattern and all existing ' will be replaced with '' (two single quotes).