Enum cql3_parser::common::RelationOperator
source · [−]pub enum RelationOperator {
LessThan,
LessThanOrEqual,
Equal,
NotEqual,
GreaterThanOrEqual,
GreaterThan,
In,
Contains,
ContainsKey,
IsNot,
}Expand description
A relation operator used in WHERE and IF clauses.
Variants
LessThan
LessThanOrEqual
Equal
NotEqual
GreaterThanOrEqual
GreaterThan
In
Contains
ContainsKey
IsNot
this is not used in normal cases it is used in the MaterializedView to specify a collumn that must not be null.
Implementations