Struct cql3_parser::common::RelationElement
source · [−]pub struct RelationElement {
pub obj: Operand,
pub oper: RelationOperator,
pub value: Operand,
}Fields
obj: Operandthe column, function or column list on the left side
oper: RelationOperatorthe relational operator
value: Operandthe value, func, argument list, tuple list or tuple