Struct cql3_parser::common::WhereClause
source · [−]pub struct WhereClause {}Implementations
sourceimpl WhereClause
impl WhereClause
sourcepub fn get_column_relation_element_map(
where_clause: &[RelationElement]
) -> BTreeMap<Identifier, Vec<RelationElement>>
pub fn get_column_relation_element_map(
where_clause: &[RelationElement]
) -> BTreeMap<Identifier, Vec<RelationElement>>
return a map of column names to relation elements
sourcepub fn get_column_list(
where_clause: Vec<RelationElement>
) -> HashSet<Identifier>
pub fn get_column_list(
where_clause: Vec<RelationElement>
) -> HashSet<Identifier>
get the unordered set of column names for found in the where clause