pub struct Insert {
    pub begin_batch: Option<BeginBatch>,
    pub table_name: FQName,
    pub columns: Vec<Identifier>,
    pub values: InsertValues,
    pub using_ttl: Option<TtlTimestamp>,
    pub if_not_exists: bool,
}
the data for insert statements.

Fields

begin_batch: Option<BeginBatch>

if set the statement starts with BEGIN BATCH

table_name: FQName

the table name

columns: Vec<Identifier>

an the list of of column names to insert into.

values: InsertValues

the VALUES to insert

using_ttl: Option<TtlTimestamp>

if set the timestamp for USING TTL

if_not_exists: bool

if true then IF NOT EXISTS is added to the statement

Implementations

return a sorted map of column names to Operands.