pub struct RoleCommon {
    pub name: Identifier,
    pub password: Option<String>,
    pub superuser: Option<bool>,
    pub login: Option<bool>,
    pub options: Vec<(String, String)>,
    pub if_not_exists: bool,
}
the data for the create role statement.

Fields

name: Identifier

the name of the role

password: Option<String>

if specified the password for the role

superuser: Option<bool>

if specified then the user is explicitly noted as SUPERUER or NOSUPERUSER

login: Option<bool>

if specified the user LOGIN option is specified

options: Vec<(String, String)>

the list of options for an external authenticator.

if_not_exists: bool

only create the role if it does not exist.