pub struct Select {
    pub distinct: bool,
    pub json: bool,
    pub table_name: FQName,
    pub columns: Vec<SelectElement>,
    pub where_clause: Vec<RelationElement>,
    pub order: Option<OrderClause>,
    pub limit: Option<i32>,
    pub filtering: bool,
}
data for select statements

Fields

distinct: bool

if true DISTINCT results

json: bool

if true JSON reslts

table_name: FQName

The table name.

columns: Vec<SelectElement>

the list of elements to select.

where_clause: Vec<RelationElement>

the where clause

order: Option<OrderClause>

the optional ordering

limit: Option<i32>

the number of items to return

filtering: bool

if true ALLOW FILTERING is displayed

Implementations

return the column names selected does not return functions.

return the aliased column names. If the column is not aliased the base column name is returned. does not return functions.