Struct cql3_parser::insert::Insert
source · [−]pub struct Insert {
pub begin_batch: Option<BeginBatch>,
pub table_name: FQName,
pub columns: Vec<Identifier>,
pub values: InsertValues,
pub using_ttl: Option<TtlTimestamp>,
pub if_not_exists: bool,
}Expand description
the data for insert statements.
Fields
begin_batch: Option<BeginBatch>if set the statement starts with BEGIN BATCH
table_name: FQNamethe table name
columns: Vec<Identifier>an the list of of column names to insert into.
values: InsertValuesthe VALUES to insert
using_ttl: Option<TtlTimestamp>if set the timestamp for USING TTL
if_not_exists: boolif true then IF NOT EXISTS is added to the statement
Implementations
sourceimpl Insert
impl Insert
sourcepub fn get_value_map(&self) -> BTreeMap<Identifier, &Operand>
pub fn get_value_map(&self) -> BTreeMap<Identifier, &Operand>
return a sorted map of column names to Operands.