Struct cql3_parser::select::Select
source · [−]pub struct Select {
pub distinct: bool,
pub json: bool,
pub table_name: FQName,
pub columns: Vec<SelectElement>,
pub where_clause: Vec<RelationElement>,
pub order: Option<OrderClause>,
pub limit: Option<i32>,
pub filtering: bool,
}Expand description
data for select statements
Fields
distinct: boolif true DISTINCT results
json: boolif true JSON reslts
table_name: FQNameThe table name.
columns: Vec<SelectElement>the list of elements to select.
where_clause: Vec<RelationElement>the where clause
order: Option<OrderClause>the optional ordering
limit: Option<i32>the number of items to return
filtering: boolif true ALLOW FILTERING is displayed
Implementations
sourceimpl Select
impl Select
sourcepub fn select_names(&self) -> Vec<String>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn select_names(&self) -> Vec<String>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
return the column names selected does not return functions.
sourcepub fn select_alias(&self) -> Vec<Identifier>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
pub fn select_alias(&self) -> Vec<Identifier>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A>where
A: Allocator,
A: Allocator,
return the aliased column names. If the column is not aliased the base column name is returned. does not return functions.